@@ -16,6 +16,7 @@ log = logging.getLogger(__name__)
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
 from quikklysdk import quikkly, quikklycore
+from quikklysdk.quikklyutils import parse_hex, parse_alnum
 
 
 def main():
@@ -33,6 +34,7 @@ def main():
     parser.add_argument('--type', required=True, help='Template ID of the code to generate.')
     parser.add_argument('--data', type=int, help='Code ID as a decimal number.')
     parser.add_argument('--data-hex', type=parse_hex, help='Code ID as a hex number.')
+    parser.add_argument('--data-alnum', type=parse_alnum, help='Code ID as an alphanumeric (a-z A-Z 0-9) string.')
 
     # Skin theme parameters
     parser.add_argument('--background-color', metavar='COLOR', help='Background CSS color - as #aabbcc hex, color name or rgb() triple.')
@@ -90,13 +92,19 @@ def check_args(parser, args):
         if not args.output_file:
             parser.error('If using --open-browser, must also use --output-file to have something to open.')
 
-    if args.data is None and args.data_hex is None:
-        parser.error('Must provide --data or --data-hex.')
-    if args.data is not None and args.data_hex is not None:
-        parser.error('Must provide only one out of --data and --data-hex.')
+    num_datas = sum(int(bool(d)) for d in [args.data, args.data_hex, args.data_alnum])
+
+    if num_datas < 1:
+        parser.error('Must provide --data or --data-hex or --data-alnum.')
+    if num_datas > 1:
+        parser.error('Must provide only one out of --data and --data-hex and --data-alnum.')
+
     if args.data_hex:
         args.data = args.data_hex
         args.data_hex = None
+    elif args.data_alnum:
+        args.data = args.data_alnum
+        args.data_alnum = None
 
     if args.image_url and args.image_file:
         parser.error('Only one out of --image-url and --image-file can be used at the same time.')
@@ -104,17 +112,6 @@ def check_args(parser, args):
         parser.error('Only one out of --logo-url and --logo-file can be used at the same time.')
 
 
-def parse_hex(value):
-    if not value:
-        raise argparse.ArgumentTypeError('Hex number not provided')
-    if value.startswith('0x'):
-        value = value[2:]
-    try:
-        return int(value, base=16)
-    except ValueError:
-        raise argparse.ArgumentTypeError('Not a valid hex number.')
-
-
 def valid_fit(value):
     fitnames = {
         'default': quikklycore.QC_IMAGE_FIT_DEFAULT,
